@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/lib/Data/Localize/Auto.pm 101877 2009-03-07T05:37:41.706351Z daisuke  $
+# $Id: Auto.pm 31768 2009-04-01 01:39:18Z daisuke $
 
 package Data::Localize::Auto;
 use Any::Moose;
@@ -11,6 +11,8 @@ no Any::Moose;
 
 sub register {}
 
+sub lexicon_get {}
+
 sub localize_for {
     my ($self, %args) = @_;
     my ($id, $args) = @args{ qw(id args) };
@@ -38,6 +40,8 @@ Data::Localize::Auto - Fallback Localizer
 
 =head2 register
 
+=head2 lexicon_get
+
 Does nothing
 
 =head2 localize_for
